@@ -1,20 +1,13 @@
-/*************************************************************************
- *  Copyright (C) 2008, 2010 by Volker Lanz <vl@fidra.de>                *
- *  Copyright (C) 2016 by Teo Mrnjavac <teo@kde.org>                     *
- *                                                                       *
- *  This program is free software; you can redistribute it and/or        *
- *  modify it under the terms of the GNU General Public License as       *
- *  published by the Free Software Foundation; either version 3 of       *
- *  the License, or (at your option) any later version.                  *
- *                                                                       *
- *  This program is distributed in the hope that it will be useful,      *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of       *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
- *  GNU General Public License for more details.                         *
- *                                                                       *
- *  You should have received a copy of the GNU General Public License    *
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
- *************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2008-2012 Volker Lanz <vl@fidra.de>
+    SPDX-FileCopyrightText: 2008 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2015 Chris Campbell <c.j.campbell@ed.ac.uk>
+    SPDX-FileCopyrightText: 2016-2019 Andrius Štikonas <andrius@stikonas.eu>
+    SPDX-FileCopyrightText: 2015-2016 Teo Mrnjavac <teo@kde.org>
+    SPDX-FileCopyrightText: 2016 Chantara Tith <tith.chantara@gmail.com>
+
+    SPDX-License-Identifier: GPL-3.0-or-later
+*/
 
 #ifndef KPMCORE_PARTITIONTABLE_H
 #define KPMCORE_PARTITIONTABLE_H
@@ -56,7 +49,7 @@ public:
         bsd,
         dasd,
         msdos,
-        msdos_sectorbased,
+        msdos_sectorbased [[deprecated]],
         dvh,
         gpt,
         loop,
@@ -64,7 +57,8 @@ public:
         pc98,
         amiga,
         sun,
-        vmd  /* Volume Manager Device */
+        vmd,  /* Volume Manager Device */
+        none, /* Single FileSystem devices */
     };
 
     /** Partition flags */
@@ -87,25 +81,6 @@ public:
         LegacyBoot = 0x4000,
         MsftData = 0x8000,
         Irst = 0x100000,
-        FlagNone [[deprecated("Use PartitionTable::Flag::None")]] = None,
-        FlagBoot [[deprecated("Use PartitionTable::Flag::Boot")]] = Boot,
-        FlagRoot [[deprecated("Use PartitionTable::Flag::Root")]] = Root,
-        FlagSwap [[deprecated("Use PartitionTable::Flag::Swap")]] = Swap,
-        FlagHidden [[deprecated("Use PartitionTable::Flag::Hidden")]] = Hidden,
-        FlagRaid [[deprecated("Use PartitionTable::Flag::Raid")]] = Raid,
-        FlagLvm [[deprecated("Use PartitionTable::Flag::Lvm")]] = Lvm,
-        FlagLba [[deprecated("Use PartitionTable::Flag::Lba")]] = Lba,
-        FlagHpService [[deprecated("Use PartitionTable::Flag::HpService")]] = HpService,
-        FlagPalo [[deprecated("Use PartitionTable::Flag::Palo")]] = Palo,
-        FlagPrep [[deprecated("Use PartitionTable::Flag::Prep")]] = Prep,
-        FlagMsftReserved [[deprecated("Use PartitionTable::Flag::MsftReserved")]] = MsftReserved,
-        FlagBiosGrub [[deprecated("Use PartitionTable::Flag::BiosGrub")]] = BiosGrub,
-        FlagAppleTvRecovery [[deprecated("Use PartitionTable::Flag::AppleTvRecovery")]] = AppleTvRecovery,
-        FlagDiag [[deprecated("Use PartitionTable::Flag::Diag")]] = Diag,
-        FlagLegacyBoot [[deprecated("Use PartitionTable::Flag::LegacyBoot")]] = LegacyBoot,
-        FlagMsftData [[deprecated("Use PartitionTable::Flag::MsftData")]] = MsftData,
-        FlagIrst [[deprecated("Use PartitionTable::Flag::Irst")]] = Irst,
-        FlagEsp [[deprecated("Use PartitionTable::Flag::Boot")]] = Boot
     };
 
     Q_DECLARE_FLAGS(Flags, Flag)
@@ -179,8 +154,6 @@ public:
     void updateUnallocated(const Device& d);
     void insertUnallocated(const Device& d, PartitionNode* p, qint64 start);
 
-    bool isSectorBased(const Device& d) const;
-
     static const QList<Flag> flagList();
     static QString flagName(Flag f);
     static QStringList flagNames(Flags f);
